Summary: LSB Desktop Test Suites
Name: lsb-test-desktop
Version: 3.1.1
# rel is passed in from Makefile so we only have to set the buildno one place
Release: %rel
License: GPL
Group: Development/Tools
Source: %{name}-%{version}.tar.gz
URL: http://www.linuxbase.org/test
#Prefix: %{_prefix}
BuildRoot: %{_tmppath}/%{name}-%{version}-root
AutoReqProv: no
Requires: lsb-tet3-lite >= 3.7, lsb-python
BuildRequires: lsb-tet3-lite-devel, lsb-build-desktop >= 3.0.0, lsb-build-qt4 >= 3.0.0, lsb-build-qt3 >= 3.0.0
%define	tet_root	%{_libdir}/tet

%description
This the official package version of the LSB desktop test suites.

#==================================================
%prep
set -x
%setup -q 

#==================================================
%build
TET_ROOT=`pwd`
TET_PATH=/opt/lsb-tet3-lite
TOP=`pwd`
# see bug 1429, short version being that rpm doesn't force the PATH env var
# to include sbin, thus since we use useradd, we force it ourselves
# (section 16.4 of fhs/lsb core doc mandates /usr/local/sbin, 
# else it would be left out)
PATH=/opt/lsb/bin:$PATH:$TET_PATH/bin:/sbin:/usr/sbin:/usr/local/sbin/:
QMAKESPEC=/opt/lsb/mkspecs/linux-lsb
export TET_ROOT TET_PATH PATH QMAKESPEC

export CC=lsbcc CXX="lsbc++" LSB_PRODUCT=desktop 
for x in /opt/lsb/lib*/pkgconfig; do
	PKG_CONFIG_PATH="${x}${PKG_CONFIG_PATH+:${PKG_CONFIG_PATH}}"
done
export PKG_CONFIG_PATH

# tetj wrappers used for qt4 and xml
cd ${TOP}/tetj
make

# Qt3 tests
cd ${TOP}/lsb-qt3
LSBHOME="${TOP}" TET_SUITE_ROOT="${TET_ROOT}" TET_ROOT="${TET_PATH}" tcc -p -b lsb-qt3

# Qt4 tests
cd ${TOP}/lsb-qt
export LSB_MODULES=qt4
LSB_MODULES=qt4 LSBHOME="${TOP}" /opt/lsb/bin/qmake
LSB_MODULES=qt4 LSBHOME="${TOP}" make

# the gtkvts part
cd ${TOP}/lsb-gtkvts
PATH=$PWD/deps/bin:$PATH ACLOCAL_FLAGS="-I $PWD/deps/share/aclocal $ACLOCAL_FLAGS" ./autogen.sh --with-no-hdr-tests=TRUE --with-no-doc-parsing=TRUE
make

cd ${TOP}

tcc -b -p lsb-gtkvts
# and now we verify it didn't fail, because tcc doesn't report build errors in tests.
set +x
failed=
cd ${TOP}/lsb-gtkvts/tests/functions
for x in *; do 
	[ ! -e "$x/makefile" ] && continue		
	if [ ! -e "$x/$x" ]; then 
		echo "failed building gtkvts sub test $x"
		failed=1
	fi
done
set -x
[ -n "$failed" ] && exit 1

# the xml part
cd ${TOP}/lsb-xml/lsb-xml2
LSBHOME=${TOP} make -f Makefile.tests

# libpng tests
cd ${TOP}/lsb-libpng
LSBHOME=${TOP} make -f Makefile

#==================================================
%install
rm -rf ${RPM_BUILD_ROOT}
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/bin

cp -pf scripts/runtime/run_tests ${RPM_BUILD_ROOT}/opt/lsb/test/desktop
sed -i -e 's:^BUILD_VERSION=$:BUILD_VERSION=%{version}:' ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/run_tests
chmod +x ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/run_tests
cp -pf scripts/runtime/editcfg.sh ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/bin
chmod +x ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/bin/editcfg.sh

# licensing
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/doc/%{name}
for lfile in License Artistic GPL; do cp -pf ${lfile} ${RPM_BUILD_ROOT}/opt/lsb/doc/%{name}; done

# the gtkvts part
cd lsb-gtkvts
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/src/tests/functions/Widgets
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/src/tests/functions/Resource_Files
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/src/tests/functions/GdkPixbuf/picfile
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/src/tests/functions/GdkPixbuf/tmpfile
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/src/tests/functions/Glib
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/scenarios
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/results

cp -pf tetexec.cfg ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/tetexec.cfg
cp -pf tet_scen ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/tet_scen
cp -pf scenarios/func_scen ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/scenarios/func_scen

for file in `find tests/functions -perm 755`; do
	dir_name=`dirname $file`
        mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/$dir_name
	cp -pf $file ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/$dir_name
done

#some special test cases need the following files
#cp -pf tests/functions/FileUtil/FileUtil.c ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/tests/functions/FileUtil/FileUtil.c
#cp -pf tests/functions/GIOChannel/GIOChannel.c ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/tests/functions/GIOChannel/GIOChannel.c
#cp -pf tests/functions/GtkFileSelection/GtkFileSelection.c ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/tests/functions/GtkFileSelection/GtkFileSelection.c
install -D -m644 tests/functions/FileUtil/FileUtil.c ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/tests/functions/FileUtil/FileUtil.c
install -D -m644 tests/functions/GIOChannel/GIOChannel.c ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/tests/functions/GIOChannel/GIOChannel.c
install -D -m644 tests/functions/GtkFileSelection/GtkFileSelection.c ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/tests/functions/GtkFileSelection/GtkFileSelection.c
cp -pf src/tests/functions/Widgets/gnome-logo-icon.png ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/src/tests/functions/Widgets/gnome-logo-icon.png
cp -pf src/tests/functions/Widgets/MyUI.xml ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/src/tests/functions/Widgets/MyUI.xml
cp -pf src/tests/functions/Resource_Files/rc_example.rc ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/src/tests/functions/Resource_Files/rc_example.rc
cp -prf src/tests/functions/GdkPixbuf/picfile/ ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/src/tests/functions/GdkPixbuf/
cp -prf src/tests/functions/GdkPixbuf/tmpfile/ ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/src/tests/functions/GdkPixbuf/
cp -prf src/tests/functions/Glib/casefold.txt ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/src/tests/functions/Glib/casefold.txt
cp -prf src/tests/functions/Glib/casemap.txt ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/gtkvts/src/tests/functions/Glib/casemap.txt

cd ..

# fontconfig files and directories
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/fontconfig
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/fontconfig/fonts
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/fontconfig/tc
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/fontconfig/results

cd lsb-fontconfig

cp -pf tetexec.cfg ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/fontconfig/tetexec.cfg
cp -pf tet_scen ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/fontconfig/tet_scen
cp -pf fonts.conf ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/fontconfig/fonts.conf
cp -pf out.expected ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/fontconfig/out.expected
cp -prf fonts ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/fontconfig/
cp -prf tc ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/fontconfig/
chmod +x ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/fontconfig/tc/tc1

# the xml part
cd ../lsb-xml/lsb-xml2
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/xml
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/xml/result21
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/xml/result27
mkdir -p ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/xml/test

cp -pf lsb-rt-libxml2 ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/xml
chmod +x ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/xml/lsb-rt-libxml2
cp -pf runtest ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/xml
cp -pf testapi ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/xml
cp -prf result21 ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/xml
cp -prf result27 ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/xml
cp -prf test ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/xml

# libpng
cd ../../lsb-libpng
mkdir -p "${RPM_BUILD_ROOT}/opt/lsb/test/desktop/libpng/results"
mkdir -p "${RPM_BUILD_ROOT}/opt/lsb/test/desktop/libpng/test"
cp -rpf imageSuite "${RPM_BUILD_ROOT}/opt/lsb/test/desktop/libpng/"
install -m755 lsb-rt-libpng runtest "${RPM_BUILD_ROOT}/opt/lsb/test/desktop/libpng/"

# qt4
cd ../lsb-qt
for x in `find tests -type f -perm 755`; do
	install -D -m755 "$x" "${RPM_BUILD_ROOT}/opt/lsb/test/desktop/Qt/$x"
done
cp -pf tet_scen "${RPM_BUILD_ROOT}/opt/lsb/test/desktop/Qt/"
cp -pf tetexec.cfg "${RPM_BUILD_ROOT}/opt/lsb/test/desktop/Qt/"
install -m755 lsb-rt-qt "${RPM_BUILD_ROOT}/opt/lsb/test/desktop/Qt"

# qt3; install all tet_scen specified tests.
cd ../lsb-qt3
mkdir ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/qt3
mkdir ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/qt3/ts
mkdir ${RPM_BUILD_ROOT}/opt/lsb/test/desktop/qt3/ts/tests
for x in `find ts/tests -type f -perm 755`; do
	echo $x
	install -D -m755 $x "${RPM_BUILD_ROOT}/opt/lsb/test/desktop/qt3/$x"
done
cp -pf tet_scen "${RPM_BUILD_ROOT}/opt/lsb/test/desktop/qt3/tet_scen"
cp -pf tetexec.cfg "${RPM_BUILD_ROOT}/opt/lsb/test/desktop/qt3/tetexec.cfg"

cd ..

#==================================================
%clean
# uncomment later. leave in now for speed
#XXX
#if [ -n "${RPM_BUILD_ROOT}"  -a "${RPM_BUILD_ROOT}" != "/" ]; then 
#    rm -rf ${RPM_BUILD_ROOT}
#fi

#======================================================================
%pre
# Need to create some group and user beforehand because
# some test cases must run as non-root user.
groupadd lsb-desktop > /dev/null 2>&1 || true
useradd -g lsb-desktop lsb-desktop > /dev/null 2>&1 || true

#======================================================================
%post
for i in .configured .start_test;do
  if [ -e /opt/lsb/test/desktop/$i ]; then
	rm -f /opt/lsb/test/desktop/$i  > /dev/null 2>&1 || true
  fi
done
echo
echo "Please make sure you have installed the necessary Xvfb package"
echo "(virtual frame buffer X server, whose name is something like"
echo "xvfb, XFree86-Xvfb or xorg-x11-Xvfb) and add the path which"
echo "includes the Xvfb executable binary to your PATH setting"
echo
echo "To run the tests, please execute the following command:"
echo "    cd /opt/lsb/test/desktop; ./run_tests"
echo
echo "You will need to run the tests as root."
echo

#======================================================================
%postun
if [ "$1" = "0" ] ; then # last uninstall
  userdel lsb-desktop > /dev/null 2>&1 || true
  groupdel lsb-desktop > /dev/null 2>&1 || true

  if [ -e /home/lsb-desktop ]; then
	rm -rf /home/lsb-desktop > /dev/null 2>&1 || true
  fi
fi

#==================================================
%files
%defattr(-,root,root)

/opt/lsb/test/desktop/run_tests
/opt/lsb/test/desktop/bin
/opt/lsb/doc

# the gtkvts part
%config(noreplace) /opt/lsb/test/desktop/gtkvts/tetexec.cfg

/opt/lsb/test/desktop/gtkvts/tet_scen
/opt/lsb/test/desktop/gtkvts/scenarios
/opt/lsb/test/desktop/gtkvts/tests
/opt/lsb/test/desktop/gtkvts/src

%dir /opt/lsb/test/desktop/gtkvts/results

# fontconfig
%config(noreplace) /opt/lsb/test/desktop/fontconfig/tetexec.cfg


/opt/lsb/test/desktop/fontconfig/tet_scen
/opt/lsb/test/desktop/fontconfig/fonts.conf
/opt/lsb/test/desktop/fontconfig/out.expected
/opt/lsb/test/desktop/fontconfig/tc
/opt/lsb/test/desktop/fontconfig/fonts

%dir /opt/lsb/test/desktop/fontconfig/results

# the xml part
/opt/lsb/test/desktop/xml/lsb-rt-libxml2
/opt/lsb/test/desktop/xml/runtest
/opt/lsb/test/desktop/xml/testapi
/opt/lsb/test/desktop/xml/result21
/opt/lsb/test/desktop/xml/result27
/opt/lsb/test/desktop/xml/test

# png
/opt/lsb/test/desktop/libpng/lsb-rt-libpng
/opt/lsb/test/desktop/libpng/runtest
/opt/lsb/test/desktop/libpng/test
%dir /opt/lsb/test/desktop/libpng/imageSuite
/opt/lsb/test/desktop/libpng/imageSuite/*

# Qt
%dir /opt/lsb/test/desktop/Qt
/opt/lsb/test/desktop/Qt/*

# Qt3
/opt/lsb/test/desktop/qt3/tet_scen
/opt/lsb/test/desktop/qt3/tetexec.cfg
%dir /opt/lsb/test/desktop/qt3/ts
%dir /opt/lsb/test/desktop/qt3/ts/tests/
/opt/lsb/test/desktop/qt3/ts/tests/*

#==================================================
%changelog
* Wed Jan 31 2007 Mats Wichmann <mats@freestandards.org>
- #1562 - revert; new fix is to result reporting in xml-test code

* Tue Jan 30 2007 Stew Benedict <stewb@aysenterprises.com>
- #1562 - fix XML_0 57 (add symlink to test/title.xml)

* Sat Jan 27 2007 Stew Benedict <stewb@aysenterprises.com>
- clean up .configured, .start_test
- offer to show test report
- find the latest journals instead of {max}e
- fix upgrade scenario so we don't remove lsb-desktop user
- add test counts to xml, libpng, qt3, and fontconfig tests
- use RELEASE tag from Makefile
- make run_tests sh compliant

* Tue Dec 12 2006 Mats Wichmann
- rework for bzr version control, 3.1.1 release

* Thu May 25 2006 Marvin Heffler
- Increment release number to 10 for official respin of test package

* Fri May 19 2006 Marvin Heffler
- Increment release number to 9 due to rebuild with newer tet package

* Mon Apr 24 2006 Marvin Heffler
- Add /opt/lsb/doc directory to files list so it gets packaged

* Tue Feb 28 2006 Marvin Heffler
- Removed duplicate entry for tests subdirectory of Qt
